@@ -168,23 +168,39 @@ class ConfigurationList(ConfigurationItemContainer):
     def __getitem__(self, index):
         return self.__values__[index]
 
+    def __setitem__(self, index, value):
+        self.__values__.__setitem__(index, value)
+
     def __iter__(self):
         return iter(self.__values__)
 
     def __len__(self):
         return len(self.__values__)
 
+    def insert(self, index, value):
+        """
+        Insert value to configuration list
+        """
+        self.__values__.insert(index, value)
+
+    def append(self, value):
+        """
+        Append value to configuration list
+        """
+        self.__values__.append(value)
+
     def __load__(self, value):
         """
         Load list of values
         """
         self.__values__ = []
-        if value:
-            for item in value:
-                if isinstance(item, dict):
-                    # pylint: disable=not-callable
-                    item = self.__dict_loader__(item, parent=self)
-                self.__values__.append(item)
+        if not value:
+            return
+        for item in value:
+            if isinstance(item, dict):
+                # pylint: disable=not-callable
+                item = self.__dict_loader__(item, parent=self)
+            self.append(item)
 
     def set(self, attr, value):
         self.__load__(value)
